# Author by songht.CMB.bnu 
# Date: 2020-12-21
#!/bin/sh



export i-adhore="/Userset/i-adhore/bin/i-adhore"
export pl_scripts="/Userset/pl_scripts"

#############################################################################################################
# Prepare dataset: MAAs.table produced by alignment.sh.														
# Description:
#	Step 1 Using MAAs as genomic markers, to detect the collinear segments among 12 species.	
#		ini file indicating the running parameters used in i-Adhore.						
#		Step1.1~1.4 prepare the families.csv and data.ini required by i-adhore;				
#		Step1.5 running i-adhore to detect the collinear segments among 12 species		
#	Step 2 Parsing the segments.txt to collect the n-way collinear segments 					
#		Output as n-way_segments.table as 6 columns including (1)segmentID;  				
#		(2)multipliconID;(3)species;(4)chr;(5)start_anchorID;(6)end_anchorID;(7)order		
#	Step 3 Transfering the table to gff3 format for collinear segments							
#	Dependency tools: write_scaffold_lst.pl, write_families.pl, Step2.pl, Step3.pl						
#	Usage: sh run.sh 													
#		Input: MAAs.table, ini which includes the i-adhore running parameters					
#		Output: n-way.collinear.gff3 [n=3~12]					
#############################################################################################################


echo "Step 1 Start at"
date
export wkdir=/Userset/
export MAAs_table="/Userset/MAAs.table"
export adhore_output="/Userset/output"
export $wkdir

echo 'Step1.1 write the scaffold files'
export genome="cucumber melo bottle-gourd Cmaxima Cmoschata pepo water-melon"
for i in $genome
	do
		grep "$i" ${MAAs_table} | sort -k3,3 -k5n > ./$i\_gff.tmp
		mkdir ./$i\_scaffold\_lst
		perl $pl_scripts/write_scaffold_lst_files.pl $i\_gff.tmp $i
		rm -f $i\_gff.tmp
	done

echo 'Step1.2 write the families table'
perl $pl_scripts/write_families.pl ${MAAs_table} > ${wkdir}/families.csv

echo 'Step1.3 write genome.lst'
perl $pl_script/write_genome_lst.pl ${genome} > $wkdir/genome.lst

echo 'Step1.4 write the data.ini'
echo 'ini file indicating the running parameters used in i-Adhore'
cat $wkdir/genome.lst $wkdir/ini > $wkdir/data.ini

echo 'Step1.5 i-ADHORE using MAAs as markers'
zsub -n1 -p8 -N i-ad30 -e "${i-adhore} data.ini"

echo "Step 1 Finished at"
date

###############################################

echo 'Step 2 Start at'
date
export reference="Cucumber"
export nway_out="/Userset/segments_table/n-way"
export 2way-n_out="/Userset/segments_table/2way-n"
export segments="/Userset/segments.txt"
export Step2="/Userset/pl_scripts/Step1.pl"

echo 'preparing n-way [n=3~12] segments'
mkdir ${nway_out}
for n in {3..12}
	do
		perl $Step2 $segments $reference `seq 2 $n` > ${nway_out}/${n}-way_segments.table
	done

echo 'Step 2 Finished at'
date
################################################

echo 'Step 3 Start at'
date
export MAAs_table="/Userset/MAAs.table"
export segments_table="/Userset/segments_table"
export nway_out="/Userset/segments_gff3/n-way"
export Step3="/Userset/pl_scripts/Step3.pl"

echo 'performing n-way [n=3~12] segments'
for n in {3..12}
	do
		perl $Step3 ${segments_table}/n-way/${n}way_segments.table $MAAs_table | sort -u > ${nway_out}/${n}way_segments.gff3
	done


echo 'Step 3 Finished at'
date





